@@ -1,37 +1,6 @@
 #!/usr/bin/env bash
-
-#############################################################################
-##
-## Copyright (C) 2021 The Qt Company Ltd.
-## Contact: http://www.qt.io/licensing/
-##
-## This file is part of the provisioning scripts of the Qt Toolkit.
-##
-## $QT_BEGIN_LICENSE:LGPL21$
-## Commercial License Usage
-## Licensees holding valid commercial Qt licenses may use this file in
-## accordance with the commercial license agreement provided with the
-## Software or, alternatively, in accordance with the terms contained in
-## a written agreement between you and The Qt Company. For licensing terms
-## and conditions see http://www.qt.io/terms-conditions. For further
-## information use the contact form at http://www.qt.io/contact-us.
-##
-## GNU Lesser General Public License Usage
-## Alternatively, this file may be used under the terms of the GNU Lesser
-## General Public License version 2.1 or version 3 as published by the Free
-## Software Foundation and appearing in the file LICENSE.LGPLv21 and
-## LICENSE.LGPLv3 included in the packaging of this file. Please review the
-## following information to ensure the GNU Lesser General Public License
-## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-##
-## As a special exception, The Qt Company gives you certain additional
-## rights. These rights are described in The Qt Company LGPL Exception
-## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-##
-## $QT_END_LICENSE$
-##
-#############################################################################
+# Copyright (C) 2022 The Qt Company Ltd.
+# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 set -ex
 
@@ -42,9 +11,15 @@ installPackages=()
 installPackages+=(git)
 installPackages+=(zlib-devel)
 installPackages+=(glib2-devel)
-installPackages+=(openssl-devel)
+installPackages+=(openssl3)
+installPackages+=(openssl3-devel)
 installPackages+=(freetype-devel)
 installPackages+=(fontconfig-devel)
+installPackages+=(curl-devel)
+installPackages+=(expat-devel)
+installPackages+=(gettext-devel)
+installPackages+=(perl-devel)
+installPackages+=(dh-autoreconf)
 # cmake build
 installPackages+=(ninja-build)
 installPackages+=(pcre2-devel)
@@ -67,6 +42,9 @@ installPackages+=(dbus-devel)
 installPackages+=(gstreamer1-plugins-bad-free)
 installPackages+=(gstreamer1-devel)
 installPackages+=(gstreamer1-plugins-base-devel)
+# for QtMultimedia, ffmpeg
+installPackages+=(yasm)
+installPackages+=(libva-devel)
 # gtk3 style for QtGui/QStyle
 installPackages+=(gtk3-devel)
 # libusb1 for tqtc-boot2qt/qdb
@@ -78,6 +56,9 @@ installPackages+=(python2-devel python2-pip)
 # Python 3 with python-devel, pip and virtualenv
 installPackages+=(python36)
 installPackages+=(python36-devel)
+# Python 3.8 for pyside. Qt for Python support for Python 3.6 will be deprecated in within pyside6.3
+installPackages+=(python38)
+installPackages+=(python38-devel)
 # WebEngine
 installPackages+=(bison)
 installPackages+=(flex)
@@ -98,6 +79,8 @@ installPackages+=(perl-Digest-SHA)
 installPackages+=(glibc.i686)
 # Enable Qt Bluetooth
 installPackages+=(bluez-libs-devel)
+# QtNfc
+installPackages+=(pcsc-lite-devel)
 # QtWebKit
 installPackages+=(libxml2-devel)
 installPackages+=(libxslt-devel)
@@ -120,6 +103,9 @@ installPackages+=(xcb-util-image-devel)
 installPackages+=(xcb-util-keysyms-devel)
 installPackages+=(xcb-util-wm-devel)
 installPackages+=(xcb-util-renderutil-devel)
+installPackages+=(xcb-util-cursor)
+installPackages+=(xcb-util-cursor-devel)
+
 # ODBC support
 installPackages+=(unixODBC-devel)
 installPackages+=(unixODBC)
@@ -139,8 +125,6 @@ installPackages+=(gcc-c++)
 installPackages+=(make)
 # Open source VMware Tools
 installPackages+=(open-vm-tools)
-# Required when building git
-installPackages+=(autoconf)
 
 sudo yum -y install "${installPackages[@]}"
 
@@ -150,20 +134,12 @@ sudo dnf -y module install nodejs:12
 
 # We shouldn't use yum to install virtualenv. The one found from package repo is not
 # working, but we can use installed pip
-
-pip3 --version
-
 sudo pip3 install --upgrade pip
 sudo pip3 install virtualenv wheel
+# Just make sure we have virtualenv to run with python3.8 -m virtualenv
+sudo python3.8 -m pip install virtualenv wheel
 
 sudo /usr/bin/pip3 install wheel
-# Install all needed packages in a special wheel cache directory
-/usr/bin/pip3 wheel --wheel-dir "$HOME/python3-wheels" -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
 
-# shellcheck source=../common/unix/SetEnvVar.sh
-source "${BASH_SOURCE%/*}/../common/unix/SetEnvVar.sh"
-SetEnvVar "PYTHON3_WHEEL_CACHE" "$HOME/python3-wheels"
-
-OpenSSLVersion="$(openssl version |cut -b 9-14)"
+OpenSSLVersion="$(openssl3 version |cut -b 9-14)"
 echo "OpenSSL = $OpenSSLVersion" >> ~/versions.txt
-
